@@ -37,16 +37,16 @@ Usage::
     scan_paginator: ScanPaginator = client.get_paginator("scan")
     ```
 """
-from mypy_boto3_dynamodb.client import DynamoDBClient
-from mypy_boto3_dynamodb.paginator import (
+from .client import DynamoDBClient
+from .paginator import (
     ListBackupsPaginator,
     ListTablesPaginator,
     ListTagsOfResourcePaginator,
     QueryPaginator,
     ScanPaginator,
 )
-from mypy_boto3_dynamodb.service_resource import DynamoDBServiceResource
-from mypy_boto3_dynamodb.waiter import TableExistsWaiter, TableNotExistsWaiter
+from .service_resource import DynamoDBServiceResource
+from .waiter import TableExistsWaiter, TableNotExistsWaiter
 
 Client = DynamoDBClient
 
