@@ -169,7 +169,7 @@ class Exceptions:
 
 class DynamoDBClient:
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.90/reference/services/dynamodb.html#DynamoDB.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.95/reference/services/dynamodb.html#DynamoDB.Client)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/client.html)
     """
 
@@ -177,20 +177,21 @@ class DynamoDBClient:
     exceptions: Exceptions
 
     def batch_execute_statement(
-        self, Statements: List[BatchStatementRequestTypeDef]
+        self, *, Statements: List[BatchStatementRequestTypeDef]
     ) -> BatchExecuteStatementOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.90/reference/services/dynamodb.html#DynamoDB.Client.batch_execute_statement)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.95/reference/services/dynamodb.html#DynamoDB.Client.batch_execute_statement)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/client.html#batch_execute_statement)
         """
 
     def batch_get_item(
         self,
+        *,
         RequestItems: Dict[str, "KeysAndAttributesTypeDef"],
-        ReturnConsumedCapacity: ReturnConsumedCapacityType = None,
+        ReturnConsumedCapacity: ReturnConsumedCapacityType = None
     ) -> BatchGetItemOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.90/reference/services/dynamodb.html#DynamoDB.Client.batch_get_item)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.95/reference/services/dynamodb.html#DynamoDB.Client.batch_get_item)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/client.html#batch_get_item)
         """
 
@@ -202,27 +203,27 @@ class DynamoDBClient:
         ReturnItemCollectionMetrics: ReturnItemCollectionMetricsType = None
     ) -> BatchWriteItemOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.90/reference/services/dynamodb.html#DynamoDB.Client.batch_write_item)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.95/reference/services/dynamodb.html#DynamoDB.Client.batch_write_item)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/client.html#batch_write_item)
         """
 
     def can_paginate(self, operation_name: str) -> bool:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.90/reference/services/dynamodb.html#DynamoDB.Client.can_paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.95/reference/services/dynamodb.html#DynamoDB.Client.can_paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/client.html#can_paginate)
         """
 
-    def create_backup(self, TableName: str, BackupName: str) -> CreateBackupOutputTypeDef:
+    def create_backup(self, *, TableName: str, BackupName: str) -> CreateBackupOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.90/reference/services/dynamodb.html#DynamoDB.Client.create_backup)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.95/reference/services/dynamodb.html#DynamoDB.Client.create_backup)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/client.html#create_backup)
         """
 
     def create_global_table(
-        self, GlobalTableName: str, ReplicationGroup: List["ReplicaTypeDef"]
+        self, *, GlobalTableName: str, ReplicationGroup: List["ReplicaTypeDef"]
     ) -> CreateGlobalTableOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.90/reference/services/dynamodb.html#DynamoDB.Client.create_global_table)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.95/reference/services/dynamodb.html#DynamoDB.Client.create_global_table)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/client.html#create_global_table)
         """
 
@@ -241,13 +242,13 @@ class DynamoDBClient:
         Tags: List["TagTypeDef"] = None
     ) -> CreateTableOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.90/reference/services/dynamodb.html#DynamoDB.Client.create_table)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.95/reference/services/dynamodb.html#DynamoDB.Client.create_table)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/client.html#create_table)
         """
 
-    def delete_backup(self, BackupArn: str) -> DeleteBackupOutputTypeDef:
+    def delete_backup(self, *, BackupArn: str) -> DeleteBackupOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.90/reference/services/dynamodb.html#DynamoDB.Client.delete_backup)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.95/reference/services/dynamodb.html#DynamoDB.Client.delete_backup)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/client.html#delete_backup)
         """
 
@@ -302,109 +303,111 @@ class DynamoDBClient:
         ] = None
     ) -> DeleteItemOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.90/reference/services/dynamodb.html#DynamoDB.Client.delete_item)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.95/reference/services/dynamodb.html#DynamoDB.Client.delete_item)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/client.html#delete_item)
         """
 
-    def delete_table(self, TableName: str) -> DeleteTableOutputTypeDef:
+    def delete_table(self, *, TableName: str) -> DeleteTableOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.90/reference/services/dynamodb.html#DynamoDB.Client.delete_table)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.95/reference/services/dynamodb.html#DynamoDB.Client.delete_table)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/client.html#delete_table)
         """
 
-    def describe_backup(self, BackupArn: str) -> DescribeBackupOutputTypeDef:
+    def describe_backup(self, *, BackupArn: str) -> DescribeBackupOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.90/reference/services/dynamodb.html#DynamoDB.Client.describe_backup)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.95/reference/services/dynamodb.html#DynamoDB.Client.describe_backup)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/client.html#describe_backup)
         """
 
-    def describe_continuous_backups(self, TableName: str) -> DescribeContinuousBackupsOutputTypeDef:
+    def describe_continuous_backups(
+        self, *, TableName: str
+    ) -> DescribeContinuousBackupsOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.90/reference/services/dynamodb.html#DynamoDB.Client.describe_continuous_backups)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.95/reference/services/dynamodb.html#DynamoDB.Client.describe_continuous_backups)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/client.html#describe_continuous_backups)
         """
 
     def describe_contributor_insights(
-        self, TableName: str, IndexName: str = None
+        self, *, TableName: str, IndexName: str = None
     ) -> DescribeContributorInsightsOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.90/reference/services/dynamodb.html#DynamoDB.Client.describe_contributor_insights)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.95/reference/services/dynamodb.html#DynamoDB.Client.describe_contributor_insights)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/client.html#describe_contributor_insights)
         """
 
     def describe_endpoints(self) -> DescribeEndpointsResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.90/reference/services/dynamodb.html#DynamoDB.Client.describe_endpoints)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.95/reference/services/dynamodb.html#DynamoDB.Client.describe_endpoints)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/client.html#describe_endpoints)
         """
 
-    def describe_export(self, ExportArn: str) -> DescribeExportOutputTypeDef:
+    def describe_export(self, *, ExportArn: str) -> DescribeExportOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.90/reference/services/dynamodb.html#DynamoDB.Client.describe_export)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.95/reference/services/dynamodb.html#DynamoDB.Client.describe_export)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/client.html#describe_export)
         """
 
-    def describe_global_table(self, GlobalTableName: str) -> DescribeGlobalTableOutputTypeDef:
+    def describe_global_table(self, *, GlobalTableName: str) -> DescribeGlobalTableOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.90/reference/services/dynamodb.html#DynamoDB.Client.describe_global_table)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.95/reference/services/dynamodb.html#DynamoDB.Client.describe_global_table)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/client.html#describe_global_table)
         """
 
     def describe_global_table_settings(
-        self, GlobalTableName: str
+        self, *, GlobalTableName: str
     ) -> DescribeGlobalTableSettingsOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.90/reference/services/dynamodb.html#DynamoDB.Client.describe_global_table_settings)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.95/reference/services/dynamodb.html#DynamoDB.Client.describe_global_table_settings)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/client.html#describe_global_table_settings)
         """
 
     def describe_kinesis_streaming_destination(
-        self, TableName: str
+        self, *, TableName: str
     ) -> DescribeKinesisStreamingDestinationOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.90/reference/services/dynamodb.html#DynamoDB.Client.describe_kinesis_streaming_destination)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.95/reference/services/dynamodb.html#DynamoDB.Client.describe_kinesis_streaming_destination)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/client.html#describe_kinesis_streaming_destination)
         """
 
     def describe_limits(self) -> DescribeLimitsOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.90/reference/services/dynamodb.html#DynamoDB.Client.describe_limits)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.95/reference/services/dynamodb.html#DynamoDB.Client.describe_limits)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/client.html#describe_limits)
         """
 
-    def describe_table(self, TableName: str) -> DescribeTableOutputTypeDef:
+    def describe_table(self, *, TableName: str) -> DescribeTableOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.90/reference/services/dynamodb.html#DynamoDB.Client.describe_table)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.95/reference/services/dynamodb.html#DynamoDB.Client.describe_table)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/client.html#describe_table)
         """
 
     def describe_table_replica_auto_scaling(
-        self, TableName: str
+        self, *, TableName: str
     ) -> DescribeTableReplicaAutoScalingOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.90/reference/services/dynamodb.html#DynamoDB.Client.describe_table_replica_auto_scaling)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.95/reference/services/dynamodb.html#DynamoDB.Client.describe_table_replica_auto_scaling)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/client.html#describe_table_replica_auto_scaling)
         """
 
-    def describe_time_to_live(self, TableName: str) -> DescribeTimeToLiveOutputTypeDef:
+    def describe_time_to_live(self, *, TableName: str) -> DescribeTimeToLiveOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.90/reference/services/dynamodb.html#DynamoDB.Client.describe_time_to_live)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.95/reference/services/dynamodb.html#DynamoDB.Client.describe_time_to_live)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/client.html#describe_time_to_live)
         """
 
     def disable_kinesis_streaming_destination(
-        self, TableName: str, StreamArn: str
+        self, *, TableName: str, StreamArn: str
     ) -> KinesisStreamingDestinationOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.90/reference/services/dynamodb.html#DynamoDB.Client.disable_kinesis_streaming_destination)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.95/reference/services/dynamodb.html#DynamoDB.Client.disable_kinesis_streaming_destination)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/client.html#disable_kinesis_streaming_destination)
         """
 
     def enable_kinesis_streaming_destination(
-        self, TableName: str, StreamArn: str
+        self, *, TableName: str, StreamArn: str
     ) -> KinesisStreamingDestinationOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.90/reference/services/dynamodb.html#DynamoDB.Client.enable_kinesis_streaming_destination)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.95/reference/services/dynamodb.html#DynamoDB.Client.enable_kinesis_streaming_destination)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/client.html#enable_kinesis_streaming_destination)
         """
 
@@ -434,17 +437,18 @@ class DynamoDBClient:
         NextToken: str = None
     ) -> ExecuteStatementOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.90/reference/services/dynamodb.html#DynamoDB.Client.execute_statement)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.95/reference/services/dynamodb.html#DynamoDB.Client.execute_statement)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/client.html#execute_statement)
         """
 
     def execute_transaction(
         self,
+        *,
         TransactStatements: List[ParameterizedStatementTypeDef],
-        ClientRequestToken: str = None,
+        ClientRequestToken: str = None
     ) -> ExecuteTransactionOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.90/reference/services/dynamodb.html#DynamoDB.Client.execute_transaction)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.95/reference/services/dynamodb.html#DynamoDB.Client.execute_transaction)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/client.html#execute_transaction)
         """
 
@@ -462,7 +466,7 @@ class DynamoDBClient:
         ExportFormat: ExportFormatType = None
     ) -> ExportTableToPointInTimeOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.90/reference/services/dynamodb.html#DynamoDB.Client.export_table_to_point_in_time)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.95/reference/services/dynamodb.html#DynamoDB.Client.export_table_to_point_in_time)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/client.html#export_table_to_point_in_time)
         """
 
@@ -474,7 +478,7 @@ class DynamoDBClient:
         HttpMethod: str = None,
     ) -> str:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.90/reference/services/dynamodb.html#DynamoDB.Client.generate_presigned_url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.95/reference/services/dynamodb.html#DynamoDB.Client.generate_presigned_url)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/client.html#generate_presigned_url)
         """
 
@@ -508,7 +512,7 @@ class DynamoDBClient:
         ExpressionAttributeNames: Dict[str, str] = None
     ) -> GetItemOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.90/reference/services/dynamodb.html#DynamoDB.Client.get_item)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.95/reference/services/dynamodb.html#DynamoDB.Client.get_item)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/client.html#get_item)
         """
 
@@ -523,7 +527,7 @@ class DynamoDBClient:
         BackupType: BackupTypeFilterType = None
     ) -> ListBackupsOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.90/reference/services/dynamodb.html#DynamoDB.Client.list_backups)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.95/reference/services/dynamodb.html#DynamoDB.Client.list_backups)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/client.html#list_backups)
         """
 
@@ -531,7 +535,7 @@ class DynamoDBClient:
         self, *, TableName: str = None, NextToken: str = None, MaxResults: int = None
     ) -> ListContributorInsightsOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.90/reference/services/dynamodb.html#DynamoDB.Client.list_contributor_insights)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.95/reference/services/dynamodb.html#DynamoDB.Client.list_contributor_insights)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/client.html#list_contributor_insights)
         """
 
@@ -539,7 +543,7 @@ class DynamoDBClient:
         self, *, TableArn: str = None, MaxResults: int = None, NextToken: str = None
     ) -> ListExportsOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.90/reference/services/dynamodb.html#DynamoDB.Client.list_exports)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.95/reference/services/dynamodb.html#DynamoDB.Client.list_exports)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/client.html#list_exports)
         """
 
@@ -551,23 +555,23 @@ class DynamoDBClient:
         RegionName: str = None
     ) -> ListGlobalTablesOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.90/reference/services/dynamodb.html#DynamoDB.Client.list_global_tables)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.95/reference/services/dynamodb.html#DynamoDB.Client.list_global_tables)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/client.html#list_global_tables)
         """
 
     def list_tables(
-        self, ExclusiveStartTableName: str = None, Limit: int = None
+        self, *, ExclusiveStartTableName: str = None, Limit: int = None
     ) -> ListTablesOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.90/reference/services/dynamodb.html#DynamoDB.Client.list_tables)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.95/reference/services/dynamodb.html#DynamoDB.Client.list_tables)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/client.html#list_tables)
         """
 
     def list_tags_of_resource(
-        self, ResourceArn: str, NextToken: str = None
+        self, *, ResourceArn: str, NextToken: str = None
     ) -> ListTagsOfResourceOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.90/reference/services/dynamodb.html#DynamoDB.Client.list_tags_of_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.95/reference/services/dynamodb.html#DynamoDB.Client.list_tags_of_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/client.html#list_tags_of_resource)
         """
 
@@ -622,7 +626,7 @@ class DynamoDBClient:
         ] = None
     ) -> PutItemOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.90/reference/services/dynamodb.html#DynamoDB.Client.put_item)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.95/reference/services/dynamodb.html#DynamoDB.Client.put_item)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/client.html#put_item)
         """
 
@@ -684,7 +688,7 @@ class DynamoDBClient:
         ] = None
     ) -> QueryOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.90/reference/services/dynamodb.html#DynamoDB.Client.query)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.95/reference/services/dynamodb.html#DynamoDB.Client.query)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/client.html#query)
         """
 
@@ -700,7 +704,7 @@ class DynamoDBClient:
         SSESpecificationOverride: SSESpecificationTypeDef = None
     ) -> RestoreTableFromBackupOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.90/reference/services/dynamodb.html#DynamoDB.Client.restore_table_from_backup)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.95/reference/services/dynamodb.html#DynamoDB.Client.restore_table_from_backup)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/client.html#restore_table_from_backup)
         """
 
@@ -719,7 +723,7 @@ class DynamoDBClient:
         SSESpecificationOverride: SSESpecificationTypeDef = None
     ) -> RestoreTableToPointInTimeOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.90/reference/services/dynamodb.html#DynamoDB.Client.restore_table_to_point_in_time)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.95/reference/services/dynamodb.html#DynamoDB.Client.restore_table_to_point_in_time)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/client.html#restore_table_to_point_in_time)
         """
 
@@ -780,23 +784,24 @@ class DynamoDBClient:
         ConsistentRead: bool = None
     ) -> ScanOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.90/reference/services/dynamodb.html#DynamoDB.Client.scan)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.95/reference/services/dynamodb.html#DynamoDB.Client.scan)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/client.html#scan)
         """
 
-    def tag_resource(self, ResourceArn: str, Tags: List["TagTypeDef"]) -> None:
+    def tag_resource(self, *, ResourceArn: str, Tags: List["TagTypeDef"]) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.90/reference/services/dynamodb.html#DynamoDB.Client.tag_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.95/reference/services/dynamodb.html#DynamoDB.Client.tag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/client.html#tag_resource)
         """
 
     def transact_get_items(
         self,
+        *,
         TransactItems: List[TransactGetItemTypeDef],
-        ReturnConsumedCapacity: ReturnConsumedCapacityType = None,
+        ReturnConsumedCapacity: ReturnConsumedCapacityType = None
     ) -> TransactGetItemsOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.90/reference/services/dynamodb.html#DynamoDB.Client.transact_get_items)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.95/reference/services/dynamodb.html#DynamoDB.Client.transact_get_items)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/client.html#transact_get_items)
         """
 
@@ -809,23 +814,24 @@ class DynamoDBClient:
         ClientRequestToken: str = None
     ) -> TransactWriteItemsOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.90/reference/services/dynamodb.html#DynamoDB.Client.transact_write_items)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.95/reference/services/dynamodb.html#DynamoDB.Client.transact_write_items)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/client.html#transact_write_items)
         """
 
-    def untag_resource(self, ResourceArn: str, TagKeys: List[str]) -> None:
+    def untag_resource(self, *, ResourceArn: str, TagKeys: List[str]) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.90/reference/services/dynamodb.html#DynamoDB.Client.untag_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.95/reference/services/dynamodb.html#DynamoDB.Client.untag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/client.html#untag_resource)
         """
 
     def update_continuous_backups(
         self,
+        *,
         TableName: str,
-        PointInTimeRecoverySpecification: PointInTimeRecoverySpecificationTypeDef,
+        PointInTimeRecoverySpecification: PointInTimeRecoverySpecificationTypeDef
     ) -> UpdateContinuousBackupsOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.90/reference/services/dynamodb.html#DynamoDB.Client.update_continuous_backups)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.95/reference/services/dynamodb.html#DynamoDB.Client.update_continuous_backups)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/client.html#update_continuous_backups)
         """
 
@@ -837,15 +843,15 @@ class DynamoDBClient:
         IndexName: str = None
     ) -> UpdateContributorInsightsOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.90/reference/services/dynamodb.html#DynamoDB.Client.update_contributor_insights)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.95/reference/services/dynamodb.html#DynamoDB.Client.update_contributor_insights)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/client.html#update_contributor_insights)
         """
 
     def update_global_table(
-        self, GlobalTableName: str, ReplicaUpdates: List[ReplicaUpdateTypeDef]
+        self, *, GlobalTableName: str, ReplicaUpdates: List[ReplicaUpdateTypeDef]
     ) -> UpdateGlobalTableOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.90/reference/services/dynamodb.html#DynamoDB.Client.update_global_table)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.95/reference/services/dynamodb.html#DynamoDB.Client.update_global_table)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/client.html#update_global_table)
         """
 
@@ -862,7 +868,7 @@ class DynamoDBClient:
         ReplicaSettingsUpdate: List[ReplicaSettingsUpdateTypeDef] = None
     ) -> UpdateGlobalTableSettingsOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.90/reference/services/dynamodb.html#DynamoDB.Client.update_global_table_settings)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.95/reference/services/dynamodb.html#DynamoDB.Client.update_global_table_settings)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/client.html#update_global_table_settings)
         """
 
@@ -919,7 +925,7 @@ class DynamoDBClient:
         ] = None
     ) -> UpdateItemOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.90/reference/services/dynamodb.html#DynamoDB.Client.update_item)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.95/reference/services/dynamodb.html#DynamoDB.Client.update_item)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/client.html#update_item)
         """
 
@@ -936,7 +942,7 @@ class DynamoDBClient:
         ReplicaUpdates: List[ReplicationGroupUpdateTypeDef] = None
     ) -> UpdateTableOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.90/reference/services/dynamodb.html#DynamoDB.Client.update_table)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.95/reference/services/dynamodb.html#DynamoDB.Client.update_table)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/client.html#update_table)
         """
 
@@ -949,28 +955,28 @@ class DynamoDBClient:
         ReplicaUpdates: List[ReplicaAutoScalingUpdateTypeDef] = None
     ) -> UpdateTableReplicaAutoScalingOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.90/reference/services/dynamodb.html#DynamoDB.Client.update_table_replica_auto_scaling)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.95/reference/services/dynamodb.html#DynamoDB.Client.update_table_replica_auto_scaling)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/client.html#update_table_replica_auto_scaling)
         """
 
     def update_time_to_live(
-        self, TableName: str, TimeToLiveSpecification: "TimeToLiveSpecificationTypeDef"
+        self, *, TableName: str, TimeToLiveSpecification: "TimeToLiveSpecificationTypeDef"
     ) -> UpdateTimeToLiveOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.90/reference/services/dynamodb.html#DynamoDB.Client.update_time_to_live)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.95/reference/services/dynamodb.html#DynamoDB.Client.update_time_to_live)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/client.html#update_time_to_live)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_backups"]) -> ListBackupsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.90/reference/services/dynamodb.html#DynamoDB.Paginator.ListBackups)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/paginators.html#listbackupspaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.95/reference/services/dynamodb.html#DynamoDB.Paginator.ListBackups)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/paginators.html#listbackupspaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_tables"]) -> ListTablesPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.90/reference/services/dynamodb.html#DynamoDB.Paginator.ListTables)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/paginators.html#listtablespaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.95/reference/services/dynamodb.html#DynamoDB.Paginator.ListTables)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/paginators.html#listtablespaginator)
         """
 
     @overload
@@ -978,29 +984,29 @@ class DynamoDBClient:
         self, operation_name: Literal["list_tags_of_resource"]
     ) -> ListTagsOfResourcePaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.90/reference/services/dynamodb.html#DynamoDB.Paginator.ListTagsOfResource)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/paginators.html#listtagsofresourcepaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.95/reference/services/dynamodb.html#DynamoDB.Paginator.ListTagsOfResource)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/paginators.html#listtagsofresourcepaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["query"]) -> QueryPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.90/reference/services/dynamodb.html#DynamoDB.Paginator.Query)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/paginators.html#querypaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.95/reference/services/dynamodb.html#DynamoDB.Paginator.Query)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/paginators.html#querypaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["scan"]) -> ScanPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.90/reference/services/dynamodb.html#DynamoDB.Paginator.Scan)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/paginators.html#scanpaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.95/reference/services/dynamodb.html#DynamoDB.Paginator.Scan)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/paginators.html#scanpaginator)
         """
 
     @overload
     def get_waiter(self, waiter_name: Literal["table_exists"]) -> TableExistsWaiter:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.90/reference/services/dynamodb.html#DynamoDB.Waiter.table_exists)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/waiters.html#tableexistswaiter)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.95/reference/services/dynamodb.html#DynamoDB.Waiter.table_exists)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/waiters.html#tableexistswaiter)
         """
 
     @overload
     def get_waiter(self, waiter_name: Literal["table_not_exists"]) -> TableNotExistsWaiter:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.90/reference/services/dynamodb.html#DynamoDB.Waiter.table_not_exists)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/waiters.html#tablenotexistswaiter)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.95/reference/services/dynamodb.html#DynamoDB.Waiter.table_not_exists)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/waiters.html#tablenotexistswaiter)
         """
