@@ -29,23 +29,23 @@ __all__ = ("TableExistsWaiter", "TableNotExistsWaiter")
 
 class TableExistsWaiter(Boto3Waiter):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.90/reference/services/dynamodb.html#DynamoDB.Waiter.table_exists)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/waiters.html#tableexistswaiter)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.95/reference/services/dynamodb.html#DynamoDB.Waiter.table_exists)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/waiters.html#tableexistswaiter)
     """
 
-    def wait(self, TableName: str, WaiterConfig: WaiterConfigTypeDef = None) -> None:
+    def wait(self, *, TableName: str, WaiterConfig: WaiterConfigTypeDef = None) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.90/reference/services/dynamodb.html#DynamoDB.Waiter.TableExistsWaiter)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.95/reference/services/dynamodb.html#DynamoDB.Waiter.TableExistsWaiter)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/waiters.html#tableexists)
         """
 
 
 class TableNotExistsWaiter(Boto3Waiter):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.90/reference/services/dynamodb.html#DynamoDB.Waiter.table_not_exists)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/waiters.html#tablenotexistswaiter)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.95/reference/services/dynamodb.html#DynamoDB.Waiter.table_not_exists)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/waiters.html#tablenotexistswaiter)
     """
 
-    def wait(self, TableName: str, WaiterConfig: WaiterConfigTypeDef = None) -> None:
+    def wait(self, *, TableName: str, WaiterConfig: WaiterConfigTypeDef = None) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.90/reference/services/dynamodb.html#DynamoDB.Waiter.TableNotExistsWaiter)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.95/reference/services/dynamodb.html#DynamoDB.Waiter.TableNotExistsWaiter)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/waiters.html#tablenotexists)
         """
